%define anolis_release 1
%bcond_with unversioned_gpg
%bcond_without unversioned_gpg

Summary: Utility for secure communication and data storage
Name:    gnupg2
Version: 2.4.3
Release: %{anolis_release}%{?dist}

License: GPLv3+
Source0: https://gnupg.org/ftp/gcrypt/gnupg/gnupg-%{version}.tar.bz2

URL:     https://www.gnupg.org/

#BuildRequires: automake libtool texinfo transfig
BuildRequires: gcc
BuildRequires: bzip2-devel
BuildRequires: curl-devel
BuildRequires: docbook-utils
BuildRequires: gettext
BuildRequires: libassuan-devel >= 2.5.0
BuildRequires: libgcrypt-devel >= 1.9.1
BuildRequires: libgpg-error-devel >= 1.41
BuildRequires: libksba-devel >= 1.6.3
BuildRequires: openldap-devel
BuildRequires: libusb-devel
BuildRequires: pcsc-lite-libs
BuildRequires: npth-devel
BuildRequires: readline-devel ncurses-devel
BuildRequires: zlib-devel
BuildRequires: pkgconfig(gnutls) >= 3.0
BuildRequires: pkgconfig(sqlite3) >= 3.2.7
BuildRequires: pkgconfig(tss2-esys)
BuildRequires: fuse
BuildRequires: make

Requires: libgcrypt >= 1.9.1
Requires: libgpg-error >= 1.41
Requires: libksba >= 1.6.3

Recommends: pinentry

Recommends: gnupg2-smime

# for USB smart card support
Recommends: pcsc-lite-ccid

%if %{with unversioned_gpg}
# pgp-tools, perl-GnuPG-Interface requires 'gpg' (not sure why) -- Rex
Provides: gpg = %{version}-%{release}
# Obsolete GnuPG-1 package
Provides: gnupg = %{version}-%{release}
Obsoletes: gnupg < 1.4.24
%endif

Provides: dirmngr = %{version}-%{release}
Obsoletes: dirmngr < 1.2.0-1

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

%package smime
Summary: CMS encryption and signing tool and smart card support for GnuPG
Requires: gnupg2 = %{version}-%{release}


%description
GnuPG is GNU's tool for secure communication and data storage.  It can
be used to encrypt data and to create digital signatures.  It includes
an advanced key management facility and is compliant with the proposed
OpenPGP Internet standard as described in RFC2440 and the S/MIME
standard as described by several RFCs.

GnuPG 2.0 is a newer version of GnuPG with additional support for
S/MIME.  It has a different design philosophy that splits
functionality up into several modules. The S/MIME and smartcard functionality
is provided by the gnupg2-smime package.

%description smime
GnuPG is GNU's tool for secure communication and data storage. This
package adds support for smart cards and S/MIME encryption and signing
to the base GnuPG package.

%prep
%setup -q -n gnupg-%{version}

%build
%global _configure ../configure
mkdir -p %{_vpath_builddir}
pushd %{_vpath_builddir}
# can not regenerate makefiles because of automake-1.16.3 requirement
# ./autogen.sh
%configure \
%if %{without unversioned_gpg}
  --enable-gpg-is-gpg2 \
%endif
  --disable-ntbtls \
  --disable-rpath \
  --enable-g13 \
  --disable-ccid-driver \
  --enable-large-secmem

%make_build


%install
%make_install \
  -C %{_vpath_builddir} \
  docdir=%{_pkgdocdir}

%if %{without unversioned_gpg}
# rename file conflicting with gnupg-1.x
rename gnupg.7 gnupg2.7 %{buildroot}%{_mandir}/man7/gnupg.7*
%endif

%find_lang %{name}

# gpgconf.conf
mkdir -p %{buildroot}%{_sysconfdir}/gnupg
touch %{buildroot}%{_sysconfdir}/gnupg/gpgconf.conf

# more docs
install -m644 -p AUTHORS NEWS THANKS TODO \
  %{buildroot}%{_pkgdocdir}

%if %{with unversioned_gpg}
# compat symlinks
ln -sf gpg %{buildroot}%{_bindir}/gpg2
ln -sf gpgv %{buildroot}%{_bindir}/gpgv2
ln -sf gpg.1 %{buildroot}%{_mandir}/man1/gpg2.1
ln -sf gpgv.1 %{buildroot}%{_mandir}/man1/gpgv2.1
ln -sf gnupg.7 %{buildroot}%{_mandir}/man7/gnupg2.7
%endif

# drop the gpg scheme interpreter
rm -f %{buildroot}%{_bindir}/gpgscm

%generate_compatibility_deps

%check
%make_build check -C %{_vpath_builddir}

%files -f %{name}.lang
%dir %{abidir}
%license COPYING
%{_pkgdocdir}
%dir %{_sysconfdir}/gnupg
%ghost %config(noreplace) %{_sysconfdir}/gnupg/gpgconf.conf
%{_bindir}/gpg2
%{_bindir}/gpgv2
%{_bindir}/gpg-card
%{_bindir}/gpg-connect-agent
%{_bindir}/gpg-agent
%{_bindir}/gpg-wks-client
%{_bindir}/gpgconf
%{_bindir}/gpgparsemail
%{_bindir}/gpgtar
%{_bindir}/g13
%{_bindir}/dirmngr
%{_bindir}/dirmngr-client
%if %{with unversioned_gpg}
%{_bindir}/gpg
%{_bindir}/gpgv
%{_bindir}/gpgsplit
%endif
%{_bindir}/watchgnupg
%{_bindir}/gpg-wks-server
%{_sbindir}/*
%{abidir}/*-option.list
%exclude %{abidir}/gpgsm*-option.list
%exclude %{abidir}/kbxutil-option.list
%{_datadir}/gnupg/
%{_libexecdir}/*
%{_infodir}/*.info*
%{_mandir}/man?/*
%exclude %{_mandir}/man?/gpgsm*

%files smime
%{_bindir}/gpgsm*
%{_bindir}/kbxutil
%{abidir}/gpgsm*-option.list
%{abidir}/kbxutil-option.list
%{_mandir}/man?/gpgsm*

%changelog
* Sun Jul 9 2023 Funda Wang <fundawang@yeah.net> - 2.4.3-1
- New version 2.4.3

* Sat Apr 29 2023 Funda Wang <fundawang@yeah.net> - 2.4.1-1
- New version 2.4.1

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.4.0-2
- Del Specific Fields

* Tue Dec 20 2022 Funda Wang <fundawang@yeah.net> - 2.4.0-1
- New version 2.4.0

* Sun Oct 30 2022 Funda Wang <fundawang@yeah.net> - 2.3.8-1
- New version 2.3.8

* Thu Oct 27 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.3.7-2
- optimise spec file

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.3.7-1
- update to 2.3.7

* Wed Mar 09 2022 pangqing <pangqing@uniontech.com> - 2.3.4-1
- Init for anolisOS 23
